# loci-client

The [Loci Notes](https://loci-notes.gitlab.io/) server API.

The Loci Notes server is a FastAPI server that provides a RESTful API for interacting with the Loci Notes system. The server is designed to be used by the Loci Notes web UI, VS Code extension, Loci Notes CLI, and any other clients that may be developed in the future.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.20240922.154542
- Package version: 0.20240922.154636
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://loci-notes.gitlab.io/](https://loci-notes.gitlab.io/)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import loci_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import loci_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import loci_client
from loci_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = loci_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with loci_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = loci_client.DefaultApi(api_client)
    api_key_in = loci_client.ApiKeyIn() # ApiKeyIn | 

    try:
        # Create Api Key
        api_response = api_instance.create_api_key(api_key_in)
        print("The response of DefaultApi->create_api_key:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->create_api_key: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**create_api_key**](docs/DefaultApi.md#create_api_key) | **POST** /api/v1/api_keys/ | Create Api Key
*DefaultApi* | [**create_note**](docs/DefaultApi.md#create_note) | **POST** /api/v1/projects/{id}/note | Create Note
*DefaultApi* | [**create_project**](docs/DefaultApi.md#create_project) | **POST** /api/v1/projects/ | Create Project
*DefaultApi* | [**create_user**](docs/DefaultApi.md#create_user) | **POST** /api/v1/users/ | Create User
*DefaultApi* | [**create_user_open**](docs/DefaultApi.md#create_user_open) | **POST** /api/v1/users/open | Create User Open
*DefaultApi* | [**delete_api_key**](docs/DefaultApi.md#delete_api_key) | **DELETE** /api/v1/api_keys/{id} | Delete Api Key
*DefaultApi* | [**delete_artifact**](docs/DefaultApi.md#delete_artifact) | **DELETE** /api/v1/artifacts/{id} | Delete Artifact
*DefaultApi* | [**delete_note**](docs/DefaultApi.md#delete_note) | **DELETE** /api/v1/notes/{id} | Delete Note
*DefaultApi* | [**delete_project**](docs/DefaultApi.md#delete_project) | **DELETE** /api/v1/projects/{id} | Delete Project
*DefaultApi* | [**delete_project_access**](docs/DefaultApi.md#delete_project_access) | **POST** /api/v1/projects/{id}/remove_users | Delete Project Access
*DefaultApi* | [**delete_user**](docs/DefaultApi.md#delete_user) | **DELETE** /api/v1/users/{user_id} | Delete User
*DefaultApi* | [**export_project**](docs/DefaultApi.md#export_project) | **GET** /api/v1/projects/{id}/export | Export Project
*DefaultApi* | [**get_artifact_file**](docs/DefaultApi.md#get_artifact_file) | **GET** /api/v1/artifacts/{id}/file | Get Artifact File
*DefaultApi* | [**login_access_token**](docs/DefaultApi.md#login_access_token) | **POST** /api/v1/login/access-token | Login Access Token
*DefaultApi* | [**read_api_key**](docs/DefaultApi.md#read_api_key) | **GET** /api/v1/api_keys/{id} | Read Api Key
*DefaultApi* | [**read_api_keys**](docs/DefaultApi.md#read_api_keys) | **GET** /api/v1/api_keys/ | Read Api Keys
*DefaultApi* | [**read_artifact**](docs/DefaultApi.md#read_artifact) | **GET** /api/v1/artifacts/{id} | Read Artifact
*DefaultApi* | [**read_note**](docs/DefaultApi.md#read_note) | **GET** /api/v1/notes/{id} | Read Note
*DefaultApi* | [**read_project**](docs/DefaultApi.md#read_project) | **GET** /api/v1/projects/{id} | Read Project
*DefaultApi* | [**read_project_artifacts**](docs/DefaultApi.md#read_project_artifacts) | **GET** /api/v1/projects/{id}/artifacts | Read Project Artifacts
*DefaultApi* | [**read_projects**](docs/DefaultApi.md#read_projects) | **GET** /api/v1/projects/ | Read Projects
*DefaultApi* | [**read_user_by_id**](docs/DefaultApi.md#read_user_by_id) | **GET** /api/v1/users/{user_id} | Read User By Id
*DefaultApi* | [**read_user_me**](docs/DefaultApi.md#read_user_me) | **GET** /api/v1/users/me | Read User Me
*DefaultApi* | [**read_users**](docs/DefaultApi.md#read_users) | **GET** /api/v1/users/ | Read Users
*DefaultApi* | [**recover_password**](docs/DefaultApi.md#recover_password) | **POST** /api/v1/password-recovery/{email} | Recover Password
*DefaultApi* | [**recover_password_html_content**](docs/DefaultApi.md#recover_password_html_content) | **POST** /api/v1/password-recovery-html-content/{email} | Recover Password Html Content
*DefaultApi* | [**reset_password**](docs/DefaultApi.md#reset_password) | **POST** /api/v1/reset-password/ | Reset Password
*DefaultApi* | [**status**](docs/DefaultApi.md#status) | **GET** /api/v1/status | Status
*DefaultApi* | [**test_email**](docs/DefaultApi.md#test_email) | **POST** /api/v1/utils/test-email/ | Test Email
*DefaultApi* | [**test_token**](docs/DefaultApi.md#test_token) | **POST** /api/v1/login/test-token | Test Token
*DefaultApi* | [**update_artifact**](docs/DefaultApi.md#update_artifact) | **PUT** /api/v1/artifacts/{id} | Update Artifact
*DefaultApi* | [**update_note**](docs/DefaultApi.md#update_note) | **PUT** /api/v1/notes/{id} | Update Note
*DefaultApi* | [**update_password_me**](docs/DefaultApi.md#update_password_me) | **PATCH** /api/v1/users/me/password | Update Password Me
*DefaultApi* | [**update_project**](docs/DefaultApi.md#update_project) | **PUT** /api/v1/projects/{id} | Update Project
*DefaultApi* | [**update_project_access**](docs/DefaultApi.md#update_project_access) | **POST** /api/v1/projects/{id}/add_users | Update Project Access
*DefaultApi* | [**update_user**](docs/DefaultApi.md#update_user) | **PATCH** /api/v1/users/{user_id} | Update User
*DefaultApi* | [**update_user_me**](docs/DefaultApi.md#update_user_me) | **PATCH** /api/v1/users/me | Update User Me
*DefaultApi* | [**upload_project_zipfile**](docs/DefaultApi.md#upload_project_zipfile) | **POST** /api/v1/projects/{id}/zipfile | Upload Project Zipfile


## Documentation For Models

 - [ApiKeyIn](docs/ApiKeyIn.md)
 - [ApiKeyOut](docs/ApiKeyOut.md)
 - [ApiKeySortEnum](docs/ApiKeySortEnum.md)
 - [ApiKeysOut](docs/ApiKeysOut.md)
 - [ArtifactExport](docs/ArtifactExport.md)
 - [ArtifactFileLocationOut](docs/ArtifactFileLocationOut.md)
 - [ArtifactIn](docs/ArtifactIn.md)
 - [ArtifactNote](docs/ArtifactNote.md)
 - [ArtifactNoteExport](docs/ArtifactNoteExport.md)
 - [ArtifactNoteIn](docs/ArtifactNoteIn.md)
 - [ArtifactNoteTypeEnum](docs/ArtifactNoteTypeEnum.md)
 - [ArtifactNoteUpdateIn](docs/ArtifactNoteUpdateIn.md)
 - [ArtifactOut](docs/ArtifactOut.md)
 - [ArtifactPriorityEnum](docs/ArtifactPriorityEnum.md)
 - [ArtifactSortEnum](docs/ArtifactSortEnum.md)
 - [ArtifactTypeEnum](docs/ArtifactTypeEnum.md)
 - [ArtifactsOut](docs/ArtifactsOut.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Message](docs/Message.md)
 - [NewPassword](docs/NewPassword.md)
 - [OrderByEnum](docs/OrderByEnum.md)
 - [ProjectAccessUser](docs/ProjectAccessUser.md)
 - [ProjectExport](docs/ProjectExport.md)
 - [ProjectIn](docs/ProjectIn.md)
 - [ProjectOut](docs/ProjectOut.md)
 - [ProjectSortEnum](docs/ProjectSortEnum.md)
 - [ProjectsOut](docs/ProjectsOut.md)
 - [StatusOut](docs/StatusOut.md)
 - [Token](docs/Token.md)
 - [UpdatePassword](docs/UpdatePassword.md)
 - [UserCreate](docs/UserCreate.md)
 - [UserCreateOpen](docs/UserCreateOpen.md)
 - [UserFullOut](docs/UserFullOut.md)
 - [UserOut](docs/UserOut.md)
 - [UserUpdate](docs/UserUpdate.md)
 - [UserUpdateMe](docs/UserUpdateMe.md)
 - [UsersOut](docs/UsersOut.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="OAuth2PasswordBearer"></a>
### OAuth2PasswordBearer

- **Type**: OAuth
- **Flow**: password
- **Authorization URL**: 
- **Scopes**: N/A


## Author

thetwitchy@thetwitchy.com


